pub struct DoNothingBuilder;Trait Implementations
Sourceimpl Clone for DoNothingBuilder
impl Clone for DoNothingBuilder
Sourcefn clone(&self) -> DoNothingBuilder
fn clone(&self) -> DoNothingBuilder
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ConstraintBuilder for DoNothingBuilder
impl ConstraintBuilder for DoNothingBuilder
Sourcetype Expr = DummySemiring
type Expr = DummySemiring
The expressions the constraint builder operates on.
It is opaque from the PoV of an AIR: arithmetic operations on it are
provided by the expression config passed to
Uair::constrain_general alongside the builder.Sourcetype Ideal = ImpossibleIdeal
type Ideal = ImpossibleIdeal
The type of ideals used by the constraint builder.
Sourcetype FqIdeal = ImpossibleIdeal
type FqIdeal = ImpossibleIdeal
Ideals living over $F_{q_i}[X]$ for the prime tuple declared by
the surrounding
UairSignature::primes. A single
ConstraintBuilder shares one runtime type for all primes; the prime
index is passed at the call site via
ConstraintBuilder::assert_in_fq_ideal. Builders that don’t care
about $F_q[X]$-constraints (counters, collectors, etc.) set
this to ImpossibleIdeal.Sourcefn assert_in_ideal(&mut self, _expr: Self::Expr, _ideal: &Self::Ideal)
fn assert_in_ideal(&mut self, _expr: Self::Expr, _ideal: &Self::Ideal)
Add a constraint saying that
expr belongs to the ideal ideal.Sourcefn assert_zero(&mut self, _expr: Self::Expr)
fn assert_zero(&mut self, _expr: Self::Expr)
Add a constraint saying that
expr is equal to zero which is
the same as saying that expr belongs to the zero ideal.Sourceimpl Debug for DoNothingBuilder
impl Debug for DoNothingBuilder
Sourceimpl Default for DoNothingBuilder
impl Default for DoNothingBuilder
Sourcefn default() -> DoNothingBuilder
fn default() -> DoNothingBuilder
Returns the “default value” for a type. Read more
impl Copy for DoNothingBuilder