pub struct DoNothingBuilder;Trait Implementations
Sourceimpl Clone for DoNothingBuilder
impl Clone for DoNothingBuilder
Sourcefn clone(&self) -> DoNothingBuilder
fn clone(&self) -> DoNothingBuilder
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ConstraintBuilder for DoNothingBuilder
impl ConstraintBuilder for DoNothingBuilder
Sourcetype Expr = DummySemiring
type Expr = DummySemiring
The expressions the constraint builder operates on.
It is opaque from the PoV of an AIR apart from
the fact that arithmetic operations are available on it
and one can check if an expression is in an ideal.
Sourcetype Ideal = ImpossibleIdeal
type Ideal = ImpossibleIdeal
The type of ideals used by the constraint builder.
Sourcefn assert_in_ideal(&mut self, _expr: Self::Expr, _ideal: &Self::Ideal)
fn assert_in_ideal(&mut self, _expr: Self::Expr, _ideal: &Self::Ideal)
Add a constraint saying that
expr belongs to the ideal ideal.Sourcefn assert_zero(&mut self, _expr: Self::Expr)
fn assert_zero(&mut self, _expr: Self::Expr)
Add a constraint saying that
expr is equal to zero which is
the same as saying that expr belongs to the zero ideal.Sourceimpl Debug for DoNothingBuilder
impl Debug for DoNothingBuilder
Sourceimpl Default for DoNothingBuilder
impl Default for DoNothingBuilder
Sourcefn default() -> DoNothingBuilder
fn default() -> DoNothingBuilder
Returns the “default value” for a type. Read more
impl Copy for DoNothingBuilder